# ---
# jupyter:
#   jupytext:
#     text_representation:
#       extension: .py
#       format_name: percent
#       format_version: '1.3'
#       jupytext_version: 1.15.0
#   kernelspec:
#     display_name: Python 3 (ipykernel)
#     language: python
#     name: python3
# ---

# %% [markdown]
# # Working with the EXIOBASE EE MRIO database

# %% [markdown]
# ## Getting EXIOBASE

# %% [markdown]
# EXIOBASE 1 (developed in the fp6 project [EXIOPOL](http://www.feem-project.net/exiopol/)), EXIOBASE 2 (outcome of the fp7 project [CREEA](http://www.creea.eu/)) and EXIOBASE 3 (outcome of the fp7 project [DESIRE](http://fp7desire.eu/)) are available on the [EXIOBASE webpage](http://www.exiobase.eu).
#
# You need to register before you can download the full dataset.
#
# Further information on the different EXIOBASE versions can be found in corresponding method papers.
#
# * EXIOBASE 1: [Tukker et al. 2013. Exiopol – Development and Illustrative Analyses of a Detailed Global MR EE SUT/IOT. Economic Systems Research 25(1), 50-70](https://doi.org/10.1080/09535314.2012.761952)
# * EXIOBASE 2: [Wood et al. 2015. Global Sustainability Accounting—Developing EXIOBASE for Multi-Regional Footprint Analysis. Sustainability 7(1), 138-163](https://doi.org/10.3390/su7010138)
# * EXIOBASE 3: [Stadler et al. 2018. EXIOBASE 3: Developing a Time Series of Detailed Environmentally Extended Multi‐Regional Input‐Output Tables. Journal of Industrial Ecology 22(3), 502-515](https://doi.org/10.1111/jiec.12715)

# %% [markdown]
# ### EXIOBASE 1

# %% [markdown]
# To download EXIOBASE 1 for the use with pymrio, navigate to the [EXIOBASE webpage]( https://www.exiobase.eu) - section(tab) "Data Download" - "[EXIOBASE 1 - full dataset](http://exiobase.eu/index.php/data-download/exiobase1-year-2000-full-data-set)" and download either
#
# - [pxp_ita_44_regions_coeff_txt](https://www.exiobase.eu/index.php/data-download/exiobase1-year-2000-full-data-set/49-pxp-ita-44-regions-coeff-txt/file) for the product by product (pxp) MRIO system or
#
# - [ixi_fpa_44_regions_coeff_txt](https://www.exiobase.eu/index.php/data-download/exiobase1-year-2000-full-data-set/25-ixi-fpa-44-regions-coeff-txt/file) for the industry by industry (ixi) MRIO system or
#
# - [pxp_ita_44_regions_coeff_src_txt](https://www.exiobase.eu/index.php/data-download/exiobase1-year-2000-full-data-set/52-pxp-ita-44-regions-coeff-src-txt/file) for the product by product (pxp) MRIO system with emission data per source or
#
# - [ixi_fpa_44_regions_coeff_src_txt](https://www.exiobase.eu/index.php/data-download/exiobase1-year-2000-full-data-set/28-ixi-fpa-44-regions-coeff-src-txt/file) for the industry by industry (ixi) wMRIO system with emission data per source.
#
# The links above directly lead to the required file(s), but remember that you need to be logged in to access them.

# %% [markdown]
# The Pymrio parser works with the compressed (zip) files as well as the unpacked files. If you want to unpack the files, make sure that you store them in different folders since they unpack in the current directory.

# %% [markdown]
# ### EXIOBASE 2

# %% [markdown]
# EXIOBASE 3 is available at the [EXIOBASE webpage](http://www.exiobase.eu) at the section (tab) tab "Data Download" - "[EXIOBASE 2 - full dataset](http://exiobase.eu/index.php/data-download/exiobase2-year-2007-full-data-set)".
#
# You can download either
#
#
# - [MrIOT PxP ita coefficient version2 2 2](http://www.exiobase.eu/index.php/data-download/exiobase2-year-2007-full-data-set/79-mriot-pxp-ita-coefficient-version2-2-2/file) for the product by product (pxp) MRIO system or
#
# - [MrIOT IxI fpa coefficient version2 2 2](http://www.exiobase.eu/index.php/data-download/exiobase2-year-2007-full-data-set/78-mriot-ixi-fpa-coefficient-version2-2-2/file) for the industry by industry (ixi) MRIO system.
#
# The links above directly lead to the required file(s), but remember that you need to be logged in to access them.
#
# The pymrio parser works with the compressed (zip) files as well as the unpacked files. You can unpack the files together in one directory (unpacking creates a separate folder for each EXIOBASE 2 version). The unpacking of the PxP version also creates a folder "__MACOSX" - you can delete this folder.

# %% [markdown]
# ### EXIOBASE 3

# %% [markdown]
# EXIOBASE 3 is available at the [EXIOBASE webpage](http://www.exiobase.eu) at the section (tab) tab "Data Download" - "[EXIOBASE 3 - monetary](http://exiobase.eu/index.php/data-download/exiobase3mon)".
# The EXIOBASE 3 parser works with both, the compressed zip archives and the extracted database.
#

# %% [markdown]
# ## Parsing

# %%
import pymrio

# %% [markdown]
# For each publically available version of EXIOBASE pymrio provides a specific parser.
# All exiobase parser work with the zip archive (as downloaded from the exiobase webpage) or the extracted data.

# %% [markdown]
# To parse **EXIOBASE 1** use:

# %% jupyter={"outputs_hidden": false}
exio1 = pymrio.parse_exiobase1(
    path="/tmp/mrios/exio1/zip/121016_EXIOBASE_pxp_ita_44_regions_coeff_txt.zip"
)

# %% [markdown]
# The parameter 'path' needs to point to either the folder with the extracted EXIOBASE1 files for the downloaded zip archive.

# %% [markdown]
# Similarly, **EXIOBASE 2** can be parsed by:

# %%
exio2 = pymrio.parse_exiobase2(
    path="/tmp/mrios/exio2/zip/mrIOT_PxP_ita_coefficient_version2.2.2.zip",
    charact=True,
    popvector="exio2",
)

# %% [markdown]
# The additional parameter 'charact' specifies if the characterization matrix provided with EXIOBASE 2 should be used. This can be specified with True or False; in addition, a custom one can be provided. In the latter case, pass the full path to the custom characterisatio file to 'charact'.
#
# The parameter 'popvector' allows to pass information about the population per EXIOBASE2 country. This can either be a custom vector of, if 'exio2' is passed, the one provided with pymrio.

# %% [markdown]
# **EXIOBASE 3** can be parsed by:

# %%
exio3 = pymrio.parse_exiobase3(path="/tmp/mrios/exio3/zip/exiobase3.4_iot_2009_pxp.zip")

# %% [markdown]
# Currently, no characterization or population vectors are provided for EXIOBASE 3.

# %% [markdown]
# For the rest of the tutorial, we use *exio2*; deleting *exio1* and *exio3* to free some memory:

# %% jupyter={"outputs_hidden": false}
del exio1
del exio3

# %% [markdown]
# ## Exploring EXIOBASE

# %% [markdown]
# After parsing a EXIOBASE version, the handling of the database is the same as for any IO.
# Here we use the parsed EXIOBASE2 to explore some characteristics of the EXIBOASE system.
#
# After reading the raw files, metadata about EXIOBASE can be accessed within the meta field:

# %% jupyter={"outputs_hidden": false}
exio2.meta

# %% [markdown]
# Custom points can be added to the history in the meta record. For example:

# %% jupyter={"outputs_hidden": false}
exio2.meta.note("First test run of EXIOBASE 2")
exio2.meta

# %% [markdown]
# To check for sectors, regions and extensions:

# %% jupyter={"outputs_hidden": false}
exio2.get_sectors()

# %% jupyter={"outputs_hidden": false}
exio2.get_regions()

# %% jupyter={"outputs_hidden": false}
list(exio2.get_extensions())

# %% [markdown]
# ## Calculating the system and extension results

# %% [markdown]
# The following command checks for missing parts in the system and calculates them. In case of the parsed EXIOBASE this includes A, L, multipliers M, footprint accounts, ..

# %% jupyter={"outputs_hidden": false}
exio2.calc_all()

# %% [markdown]
# ## Exploring the results

# %% jupyter={"outputs_hidden": false}
import matplotlib.pyplot as plt

plt.figure(figsize=(15, 15))
plt.imshow(exio2.A, vmax=1e-3)
plt.xlabel("Countries - sectors")
plt.ylabel("Countries - sectors")
plt.show()

# %% [markdown]
# The available impact data can be checked with:

# %% jupyter={"outputs_hidden": false}
list(exio2.impact.get_rows())

# %% [markdown]
# And to get for example the footprint of a specific impact do:

# %% jupyter={"outputs_hidden": false}
print(exio2.impact.unit.loc["global warming (GWP100)"])
exio2.impact.D_cba_reg.loc["global warming (GWP100)"]

# %% [markdown]
# ## Visualizing the data

# %% jupyter={"outputs_hidden": false}
with plt.style.context("ggplot"):
    exio2.impact.plot_account(["global warming (GWP100)"], figsize=(15, 10))
    plt.show()

# %% [markdown]
# See the other notebooks for further information on [aggregation](../notebooks/aggregation_examples.ipynb) and [file io](../notebooks/load_save_export.ipynb).



"""
Various constant values

KST 20140903
"""

import os
from pathlib import Path

# path information of the package
__ROOT = Path(os.path.dirname(__file__))
PYMRIO_PATH = {
    "test_mrio": Path(__ROOT / "../mrio_models/test_mrio").absolute(),
    "test_mrio_data": Path(__ROOT / "../mrio_models/test_mrio/mrio_data").absolute(),
    "testmrio": Path(__ROOT / "../mrio_models/test_mrio").absolute(),
    "test": Path(__ROOT / "../mrio_models/test_mrio").absolute(),
    # TODO remove "exio2": just here to keep the tests running
    "exio2": Path(__ROOT / "../mrio_models/exio2_pxp").absolute(),
    "exio2_pxp": Path(__ROOT / "../mrio_models/exio2_pxp").absolute(),
    "exio2_ixi": Path(__ROOT / "../mrio_models/exio2_ixi").absolute(),
    "exio3_pxp": Path(__ROOT / "../mrio_models/exio3_pxp").absolute(),
    "exio3_ixi": Path(__ROOT / "../mrio_models/exio3_ixi").absolute(),
}

# generic names (needed for the aggregation  if no names are given)
GENERIC_NAMES = {
    "sector": "sec",
    "region": "reg",
    "iosys": "IOSystem",
    "ext": "Extension",
}

DEFAULT_FILE_NAMES = {
    "filepara": "file_parameters.json",
    "metadata": "metadata.json",
    "download_log": "download_log.json",
}

MISSING_AGG_ENTRY = {
    "region": "Unspecified region",
    "sector": "Unspecified sector",
}

STORAGE_FORMAT = {
    "txt": ["txt", "tsv", "csv"],
    "parquet": ["parquet", "par", "parq"],
    "pickle": ["pickle", "pkl"],
}

# The default column name for the value column for long table format
LONG_VALUE_NAME = "value"


#  Download links for Gloria MRIO files
GLORIA_URLS = {
    "053": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACPnp0qOD1N7CSjv0reFKSba/previous_releases/053/MRIO/GLORIA_MRIOs_53_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACD6UmIBqbmkAQiAOfX7U_fa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD6y_13ul9SZnJkPV1GhZCza/previous_releases/053/MRIO/GLORIA_MRIOs_53_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA5bFH6uzjqhm6fowdMlkyLa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB3PLbnxPHIP2MGN8S36ZUBa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABIfGIVZkelhq58Ij1DKO1Va/previous_releases/053/MRIO/GLORIA_MRIOs_53_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAqOhcAo8jFU_GhTu1fzOKWa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABspySp6y4Jh2OaLrTlSeY_a/previous_releases/053/MRIO/GLORIA_MRIOs_53_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABAXczzTGbWj8i-ho0fSTsLa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABK94uXvjIdWzrgCP5uxk6Wa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABTfP3rpj_QkIPyPIJqVo62a/previous_releases/053/MRIO/GLORIA_MRIOs_53_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABW9BpSx6h83gpmyCnVfKZ-a/previous_releases/053/MRIO/GLORIA_MRIOs_53_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADvhpsqMor0wvNFLD-zWcRAa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADS3ffwpUxjkoLlQneJrrUDa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABdMfXMCF6b3HqTJEjyQkTsa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAfHBfF-5N0ZaYr-gwfJKSya/previous_releases/053/MRIO/GLORIA_MRIOs_53_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADWa9MT3qH_YAVwlqb2-eEBa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABT4WkwUQt_5KbPsWMgUUFba/previous_releases/053/MRIO/GLORIA_MRIOs_53_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABfxaEEsKc8MKndscJMxilha/previous_releases/053/MRIO/GLORIA_MRIOs_53_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB7j7bikNb1q3RhTyyLB9mQa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABrkCHIOdLU5zUmHuI8nDKma/previous_releases/053/MRIO/GLORIA_MRIOs_53_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAW_BEqaeIvAzmFE6oYz8rKa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB2ktuivgPwclQXVNQbh_Afa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADyg36facQvwueC6r85yEY8a/previous_releases/053/MRIO/GLORIA_MRIOs_53_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA7Z0xEExKNK91GvinGGk9va/previous_releases/053/MRIO/GLORIA_MRIOs_53_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD1rYcXCwCvNxC4wV8apUFCa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD-J1n98SSYniRLSNfEe0kJa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAQc9jieTHGraE9nRGha1g4a/previous_releases/053/MRIO/GLORIA_MRIOs_53_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAzRQsWiNc6Wu_5mOXAV1YIa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADPrsw4iWytQ9ItCpJ8ZqwIa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2017.zip?dl=0",
    ],
    "054": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC7K5dfdnOA3I_CJm4Bu0nHa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACO5ce_FtnXN-w8ZykcqrCYa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACvnqqeofEQPAG0X-BWxNRta/previous_releases/054/MRIO/GLORIA_MRIOs_54_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABXuHtPoMajYNR5YH18Frf_a/previous_releases/054/MRIO/GLORIA_MRIOs_54_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACOfDR7Jtk83cEzFQwktbGja/previous_releases/054/MRIO/GLORIA_MRIOs_54_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACmf_zQswJz60ZWzorQ6Bpua/previous_releases/054/MRIO/GLORIA_MRIOs_54_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADXNVDIgSjiTq2XYZBOp3TXa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABpxrh-7mFDL6va4d6Z3E_za/previous_releases/054/MRIO/GLORIA_MRIOs_54_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACwD1DOvsiLNxsMreU3Vo3ua/previous_releases/054/MRIO/GLORIA_MRIOs_54_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABlYAdTmli3iDfM3li2OAxxa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB-HUu421eE7VkH0yQV6KwAa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACqNzqTjYXrR6cJ7fpp2-_ua/previous_releases/054/MRIO/GLORIA_MRIOs_54_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABPAFDyayr8LUfTr1R8F6DAa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB1In5emdB928-a0B1j_Uo0a/previous_releases/054/MRIO/GLORIA_MRIOs_54_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABHnhwWKGOYcSMyXFxCS7Dfa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADZ2etvFvgEUOoCWRHgfUcNa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB5bz-aVrQVkj5ZSuAuGhuAa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACHEcV9TmcUUIXxd2trwzj0a/previous_releases/054/MRIO/GLORIA_MRIOs_54_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAADEQMUbcrbfItvHEgs9Tqxa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAAC8oUPc0Bf_xpiS-vMeWNa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACiG4RqHNhtOTvNkqPGvFEsa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA7I_SrhI8gklR7Za2drsNFa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACmGlhuY9zeijQCdllbwkdpa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD8snAscs6LFBF4mRlo7qsfa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACr37Rp_r7nbxaUgv8TzvlHa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAujo-1iMVSz7N3ozLLN3Zga/previous_releases/054/MRIO/GLORIA_MRIOs_54_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAt3nE7WeWQxzkeVtabsm4Sa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABFO3rlAXAI9MuZfd-KQ-9ia/previous_releases/054/MRIO/GLORIA_MRIOs_54_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB4j8NBysXu4MkgvZYmrSwfa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC-XyiKcDOn9TYmeDPKjyfna/previous_releases/054/MRIO/GLORIA_MRIOs_54_2007.zip?dl=0",
    ],
    "055": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACmYOJiT8mK1uHLQlCgn4Oya/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD11mTRGEtcqf1dRMFtQrYza/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAljBvDe2kgEL7AjDOPfF5Ca/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACdxKvPfZo8JzkQIJxbo3rxa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFPwnkn4sWCdzmxXTXNLJKa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABnBRFa0IY4iS8yU3U3bQ-ca/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC1Ms5inScRNGD_UtqRZ4cba/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABzqn-iNshbGn3PV2rDgOEma/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAfXq94cK9HgqDGRw0Av51Ra/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABPCBRPcNkDgIKV0f4Aoh-aa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABeYfN4oPwiHGMVvrdM2H7ia/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABbWD78TEiNbnZs5pZkMNSaa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADwlWrpZShpxWm0frKPU3Aja/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFSmp0PcO7UeRmC8xokRwea/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAc6MD3-u6nvoPgg3cL9tvoa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC2cg37BrUzSg3pQg3CxnLDa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACF6A0mQQ9UwvsBKCU05z0va/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAATYbJBOR6XHN6H4QRAC6tFa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAJ-gud5eL1kgvJvXAT-3zja/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA5EQmc0cDiVe6KfOsnZXesa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACTtJbqQWeSNVe1Z0jYJ_rra/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADttP2Z4KGdU4mnd58f0w2Sa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADS7y82yMnifEnpPHPuoxITa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACSkVqnHjhc1k9NY_3uDgJFa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADxMiz9payAd6cpgxoUDIw4a/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC9BjOyOaaSENX_DfMcIU-qa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD3y0caXYJPtvvZezhXEQUUa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAF9FaRBH7Hk1r48GYcilfGa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACyvsy2YPCAFqBgHC2YZWaba/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADSHS7zJ05U5Zm4FUtrldpRa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA_hJiYUEo8gVZbqp7HCgMPa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2020.zip?dl=0",
    ],
    "057": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA6XcwTY5cPBHfE7FDg9ekSa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAEU1NHMpIRHtbMTJGzX-hya/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD5JjkTWAs84_-CarcY0sf-a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACvyY2AWTm5E6g33GTjuUX3a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC0kZH3hMJzFD0zOSV-hXqYa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB2T0crYxuweitpotYGgql5a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB1pCSAiRrNdLocI-utrzUQa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC3dPPybkq_4hjJnDO_0LANa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAacUC2yoruzbtfCu7S7lc_a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACjI39Ah1YsvN6ybdTWoOtGa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAax8DaONief8spCaFSPhHBa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAfv2dQN-j2Er0Ki7EEJG7Za/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABgP-Vc2CYHZDHEgXIe9TLfa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABOEQygV5SNhbtURn5qhirsa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACpcnLaFa1PVeJhS7sPiJD4a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAZko6iV75_8T8s-5W4fsnHa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABnx3q63E2awnzGPZEXz4dZa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAvxvKCIYr3GnBgQx-wmrWda/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADltNbHhQbVFiu8gs2m2bL5a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABYaJUomI88jntKgiIDmvAYa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAALWip1Lqi_HGlzMgcOaGRGa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAAc1pEMM9q306ERP8UzrVia/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD5iMVB7im7drGO_FaE6Nr6a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACLbEdxbIFpJbXgtycjs6tIa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC2HunFEPQMtgMVXR4Jwg2ea/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABIX8KqWfAiVMpUlt2Nz2hqa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABI6JADz72WnzbA58-SAf_ja/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACOHJyTKwE3PWkxRd4B9Nmqa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADgJrD36TjnbBWmLZXxC8u_a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC1LkXZXFL8wy0BZTu3YU_ma/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABZDIIyPZIEYtbrqNlegtL4a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABFNKBuvtUG1UAOyQCG2Lxna/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADi2bZiNI6MRi825OwfsR7ea/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADHNM6TLsYY7indEpkFd7FOa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA4eTO9UoUdBWKT0oe0oRcMa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFYVV1HW0wLhGoFcjmCEkPa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADeVxiyJwJS6kJhfafnHSqTa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACWuruYd7h2x3YDJBz281soa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACLs5vplfc10hSS1KENlpmca/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACqlo7EDAc3FSrxALPG4DHZa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADx7F9gH87Dc6LDPzf3fcTya/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABDSFS4prMK_4mRgbvikoPHa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADx-PVv5sC-EFjhUwiqjxg5a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAOlf5PPkxIlJtjRjdndh56a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABjSmFGcB94WqnUfC0NxfIja/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC8O7HuVYMgqv7pxkqimsWRa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAqXP-avzvdd15VGUoEE84ma/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACw7DFT-ocxhjsH6RyoiWNka/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABh5ctBTx-JF_h7iCP6GyUUa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABF3xC3yphEq2bxphygkB8ka/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACwp-KzY3Mro5XRHqmhWgHWa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD5UwUUT3vdDc0yhjpkejkBa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAdJRkNO76p5RR3b83XaI-Ua/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACjKEAKrIi9cx0In_8hDKSba/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABm_O4Wmqn3cbPq8HhdBcXOa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADBd996bMTdUYJYIT5--kYSa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABF6jBVtrWjXAQoqRMsGTGoa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAmN2PJAf1LOL22tPpNEr2Va/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAChcWu19A7qb2nfclQQQTqda/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7p64prYW_KYDEho4I0-qxa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABe87Xzy5DQDyge34VQlGs2a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADTJExBV0XtMQtP2hC6j5S_a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADMRtFKFzt7Mh4YB-4DVMDza/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACDRHQP9X1k-UAOjY5ymX_qa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABSay731cFtpDVVuzmGhHOea/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABdYrSjF9uxt_qvLX4ot1Eva/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAdIS4iY9GiuyS8sOmGG3EZa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC8Q84V-OCsaqmFEOUw7d7Ua/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAPBHeohNkCngHYIy72EGIEa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAfkUgvpXCah6kB_39G57CGa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7lHRnfjpZ70E459aaGA7wa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADHdG-CyCm057Wuh0ZS1oTVa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADc5FEJ86TOlZirJA1ao0_ka/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADe_F-Swg5_BbBecGsFmWt8a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAByiBs3VtV9louQf2EtYaFsa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABPn1_2mNrwOQOPHTO54XbJa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACVMxOQl_p1i4jA4vSzcf_Va/previous_releases/057/GLORIA_ReadMe_057.xlsx?dl=0",
    ],
    "059": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABYYsdfwd4t0sgt6UQKGW8Ya/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADnynCU-aKsMX9kk6n0tUvTa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7c-bfG4N0qt5BKOnjIM3La/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABsyp2R_ct1yu_hODaFDtOaa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADUH7KmNh8gCdK2ZVUfBK9ka/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABqFE_P6YAkkuQszzIZISn0a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACHdzbRnvx1laL0dNQkp1T6a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADfR5w1bN2ZixOo1hmuVXyea/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC71K3VxYBwrMrXmsdhc0A9a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB-wTaCjSuldHo0PNfI8cHfa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACwZP1tlf2Qb8U_D_H4xQUja/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACuVV3GaYexY-vYg-omW1mya/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABKuG0A7TAolAL4rNQ4QLqja/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACTH-ud2dw8ldKiVAofv8AXa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADwR5isYDbjRVLAyp1PVI5ga/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAeb2Dwu51KHWlXjee34HpUa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAANcXP3JJpDCtQlPjT2B_Pya/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB5t5MNOWKHEsGUmmxs6H7Na/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACZV-0TWU3sEIY5GjNdwC4Ua/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABUvrUozc1xwvLsQh9y_JDpa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC4KGu1X4rPwmUsoBmqv6PAa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACkzjMP5FnbGusvix0MA15qa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7otFAX0-41_jaIhy_ZczFa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAoZCRgkzeBoduOHptss2cha/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC8VkCE7rpnHNqSS6R-Bw3xa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAADgEbJVwrVcOrPXsSWxbLKa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACAxqOI-H6I6bFHZWJ2YCMwa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA69qMZDCahQcgmPNCThSBwa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADYDClolKFUsSE1Y6o6ftyJa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAbqfOTmMlr2gp7c_PBvkOja/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAbXjQvMJ5e1EbMq1g-iP73a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD8QVqW1wQWpHbX6GAVyqNea/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAACbZOBtu8OC5ashBa5f_kba/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADyEnDJTr6yVsAaY5tkC4E2a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA65q1b0ikO9GMWQI5k5U7la/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAmo9y0blTG77_PK3dC_tYya/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACOld8AXWJrJcb31-UokhrHa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADYt7OKTqQDRwSer-TeDJlKa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABB8f1we-FhAQXpMe5mxWG7a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADx92sK9wI4DHLc9-yYtHufa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADjaG75JFlxCDbckU4SieRaa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADB_tZsfwsEiZRKOd03dV6ia/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACIXtkLlDmW5R-ZjGvYi57Qa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADH7RtSusEOslpe7kyIhsvEa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACKWSmKYViXTLYBpG6Jf1Ffa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADj98e6-qWZs-t-8Dke1ZiKa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADyJX_CCq6Jt17m0Rney_cHa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA_OGQqIhWIy93mQ8ARN9jXa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAkvoLbRqu0WMTtRZwrEILRa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA0mFolJm0dxJ4GFTc4mN13a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADq998BYk9J1CzOjtFwGqOZa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABMn33RAmbolGXq2Pb9b4Wka/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADKKNiln5HjNQB8IB6kUTKta/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADuVIM89hBj5RF1eeu2B07qa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADgkb8iSE3ndGw0VO9ijSWaa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACyMSQqYORqs2J8tgdVWRw_a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACEYZqic1WtOWphIOgFoBQZa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABpLIzmzKSGnmDawNfEiMJra/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA6ZwAZd2YGTDODz3X8BQY3a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7p2twdLVBn7_Ma6f_T5O8a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADh_VCk5P1l-mXWLJ6yCT0Xa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAClhxk2FW3coyYNrKCH5T7ha/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAEIZeHCQ_IBQqFTiJ5HZkya/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABfegadZLtayvxFvCJF7SR7a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC4YFJzlmqlmEyJ_dJMXpeFa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABhPhw9R3eweXFabbVrG5nAa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADctOuMcGUp5yW46XOdql2Ja/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADwR34CAYoOEDUCuGWa0jfHa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAKnTf2eSXyhmWjxwzMyAewa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACuy8sqT-jDaVuw6eiYkdIDa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC8I3418CZ7HXVsHpjU2TTea/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADIJV3Af0quGGV2hsnOc-U8a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACud6Xt3vPEyIkzEAu4CYbAa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACGy9iQIpsn9gigppfX7GZla/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACJ814P9-jR3SmTWdnOTVmAa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC-vQpAqKoxT3dFTcxgwAKJa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABagKTX5hXyqk2Rgor9S0jba/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAGVEWD6RLTSMDgaQjqeqZKa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABw5dyUYvEAWbG8n9-yXAPqa/latest_release/GLORIA_ReadMe_059.xlsx?dl=0",
    ],
    "059a": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACC_m_D32e_XUclwARi19g7a/latest_release/059a/GLORIA_MRIO_Loop059_part_IV_commodityprices.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACZlIzKDAi29CzU792I_nYRa/latest_release/059a/GLORIA_MRIO_Loop059_part_IX_datasourceintercomparison.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADxD5b95lLfPk6wRVzhI402a/latest_release/059a/GLORIA_MRIO_Loop059_part_V_footprinttrends.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADyAoZhZ8Xl2YsjOOZU7bhPa/latest_release/059a/GLORIA_MRIO_Loop059_part_VI_Diagnostics.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAZuY3C4qbPysaGRMFEnCy7a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABIg72BYQFmYQxBGAAeCm2Na/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADKTkkUNbdm97c38IrDRB8Ca/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADCkyxJKrOkPZ3fjwrcmU-Ua/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB5J8qmGICClI4WQlvpa3jaa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAgw1YO3mkFdbBZUn572ETKa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAAm3ehiXI3owONVde9eGxda/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC5vcUu2MKAu1xODSy9YRgea/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADfhrQAwCx-Ofi_cMKxz1l_a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAASfo0SxpUkE1mAEWwe3Lyaa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABImpkuGeUs2UyX1K9AFcVJa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADtBmrTwrLnjljr-uWkbIcAa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABrYYR4pDGUr7jdKQtVaM7Za/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA1bUtqsrv5XcRjI36PcIOYa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC009lzhGLbkVxf6HkyHfl3a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADu4VUfjsnnRA6-3rAbtjYJa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABSWsYcORL_M_HXV_o-6lTfa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC23_DGq9w5MpjoGuWtBJQ6a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD_o_SGwU8oF5QhxlpTyZwNa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABcHpg7E-De9cgqnbsSI4V1a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACeN8I7Q1wUR4gvA0CTYpNWa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADM4PntKaJLN3bzO1Ez6pNka/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACZfF_uHSlBe7qZxurlV1kka/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADsRWheT2tZaYbilQ-zWfCUa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFqhH-yQoQKzhARvDzv2fua/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAk6_-OGISSnyzVqZkU4ncHa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABld6xF0Vx8laejZxo85uNJa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD6RpUY_4ph-ee0TIe4ypAsa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB2aK_ut48RZQRjcc_qTQoKa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABYllMh9jBrdUprBdEIkgXSa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAByzV2RBWZI_wKiDiVDKVpia/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAiHM6jqNDhB3HA36Cc92QEa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABj-GFI6AEc6arTUkR5Gvb3a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACSI4hoS_QEsxYc0MGm7SAoa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABcbIaWUMeGjCyC-OaRoUzAa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABv8rlwnmXO8Ko3odzLfluHa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACkDV1EcXSRu-Is8owA353na/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADk2bGu84P8j997elHdA0-ta/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD-R6NueTusZ_SJL-4ElU8Ta/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACCBBzZX9pQ7rbD4hUV19HGa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABm3ZXfajKK6DMuzKpaQVsoa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADcv0zcCYyEcPoieqaHDj7ha/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAodGVLiGA6DLk_4SkrTR_da/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACpAjOOqidjnjvF-kbbR5Nua/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADQV9hpK1f_ZKTPGtskxCQga/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB7SkDSiorEhtdysH97lPbqa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABNWNZppaR8jPUC4ThOvn4ua/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACp-2HVGqW3I4-KzbDoaEBPa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABn7FF1GYWMcHudTrCU9UBZa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACPH2jDeYRlegcO_V-b8z0fa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAUDrB21dzvvqOvkkVeF5ZJa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACRzhq5aNgIBwkaCGA7IjwQa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADzWmevcioBPKyIXLFeo1z5a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACq2wDe6RctazXI4vXtmkBia/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB-nzy3HHKP16krr_ETAyMwa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABLWVkhl2OmE8nFjzhl5no1a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAQh-UlDHC8RNK8ihjIxLtha/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAwtwL1DEjrHgrAwelG2zdva/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD_X5dXAqqjxVt2ptR5T51Wa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAuaXZ3uYHbXYvI6_HFxQOHa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAJ2c_aPmR1zsehnyfp2JtBa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACzSqFH-mTqouDM4YUiszbqa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADa6iKQuNluwhSBmDtFdOaWa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAi-Z7OvotiZylyCTL75fNea/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACh20dPllzJDR2DYm31q9w3a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA4BrI28S7swRyTGdRz278Na/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC4IaWAfTggUNpU0mUJiQLAa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAMe5w8IlsI7SNfOWaJKlv2a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA5HXW36Ki0WqpBdnmxCGXXa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAh7URYNcgBAJvlZdMiTs7ca/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADx5cnuvvEQIttkRApTlNhla/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACMumxcsLjGgrNV4dtvI445a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABuMvb1onuwFj6049fvlvyWa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABwfza6j6BtHD3qSjSdfEr5a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACrChYEp68kffU3iUKIP19ua/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADY-qxXpIeyML2LNxP5P17ta/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADoCYLhwW_XZzhUyHaO5_Xda/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAArmAZ401qackDhz-3eqBXOa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACoPtVa7FM3jbUNOW-CCWt4a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAbCQ4lrX7XdELz8yKq7hgga/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADy9bgiPkVHKju40KWAqp7ea/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACe7k4X13o1FhdrR9bGDkzva/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACRuG5UmMm7jQAgpkoNWinUa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAG3cq_s1ovV4r2PpdT4CJTa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAcAqczBCyX1-Gb2jGx6LJia/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADP6IUspF03_-ScrqxWGOYca/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABbYE-_7BzSw-nyAaof4Gqwa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAQKOtnXMn5RBkJg_Z7fU7la/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAACzsyOd-FAMsbR08BHSP3Ma/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABoGJAdadDU0l1QSYX90INDa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADiaBTC4u5vhFD97lFctT5Ya/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABK_1Lg2n4joR7bJG0ku8cza/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC2mFvRl_bTJW7ILLx7VJaea/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACC1HRarAQu92dqXVsZ1eZra/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABWEueWQotoT9D6wv2rUdw_a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA0OgFD61kZPCYQm-jzTelQa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABSVI8rowLH_dVlQaEdh0HOa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADuQe7pvRK2XOuGvdLETALca/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB84ILtm8pBZYU9gjzPqDO3a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACy7fHMKoxUg-GY54-Ph3RBa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADbtJhGsj9-0PXx4OoOessDa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAASFzbOYKYJqRzLJGg4tFA3a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADJxbyn485Zkac9gCqVwko4a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA6NYtvGIQtcd9Ds5OZFX3va/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD_3co6LC7NdoXS49z6EuqIa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADMiTDO1lxcRpdWZD3AUsG3a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAO7YCQwaTK3Z7Il9IkSBKka/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADfiZsOpQPJwDptRAL9WJEHa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABQdtWCzpF-df1TEBUIvzRMa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADTHd-Czn9d8Kths6A33_f5a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB_LOozNk-NdSC_YnAp6ROXa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACcdymoASi-070OwJ75yZmza/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACrp7OZGj53sBmz9e3xacI0a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADa3ZTaZiVK3O4_D57QUwrBa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC0NjjWRQsTZg7NVCmXV7Spa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAACjEG5KLnCpJAL1Ce5-kkca/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFQmRuxxaE-4qw3UWcU4uLa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABmWnrDE-nhbKokOv-hYOXEa/latest_release/GLORIA_ReadMe_059a.xlsx?dl=0",
    ],
}



# ---
# jupyter:
#   jupytext:
#     text_representation:
#       extension: .py
#       format_name: percent
#       format_version: '1.3'
#       jupytext_version: 1.16.4
#   kernelspec:
#     display_name: Python 3 (ipykernel)
#     language: python
#     name: python3
# ---

# %% [markdown]
# # Pymrio Tutorial
#
# A complete tutorial covering all top-level functions of pymrio, using the test MRIO system.
#
#

# %% [markdown]
# ## Setup and Installation
#
# Before starting this tutorial, make sure you've got pymrio installed. You can grab it from conda-forge or PyPi.
# Use pip, mamba, conda, or whatever package manager you prefer to get it sorted. For example


# %% [markdown]
# ## Getting Started with Test MRIO Data
#
# We begin by importing pymrio and loading the test MRIO system. This small test system contains six regions and eight sectors, making it ideal for learning purposes.
#
# Note that any other MRIO database can be used with the same functions demonstrated here.
# The test system serves only as a representative example for larger, real-world datasets. See the other notebooks on MRIO downloading and handling (for example for [EXIOBASE](working_with_exiobase.ipynb)) for more details.


# %%
import pymrio

# Load the test MRIO system
test_mrio = pymrio.load_test()

# Display basic information about the system
print(test_mrio)
print("Type of object:", type(test_mrio))
print("Available extensions:", test_mrio.extensions)

# Get regions and sectors
print("Regions:", test_mrio.regions)
print("Sectors:", test_mrio.sectors)
print("Final demand categories:", test_mrio.Y_categories)
print("Extensions:", test_mrio.extensions)
print("Rows in emissions extension:", test_mrio.emissions.rows)

# %% [markdown]
# ### Search Functionality
#
# Pymrio offers comprehensive search capabilities to find specific accounts, regions, sectors, stressors, and impacts:
# The terms are the same as the pandas regex method names and work in the same way.
# For more details, check out the [explore notebook](explore.ipynb) and the [pandas regex documentation](https://pandas.pydata.org/pandas-docs/stable/user_guide/text.html#working-with-regular-expressions).

# %%
# Search for specific terms across the system
search_results = test_mrio.find("food")
print("Search results for 'food':", search_results)

# %%
# More specific search methods
contains_results = test_mrio.contains("electricity")
print("Contains 'electricity':", contains_results)

# %%
# Search within extensions
extension_search = test_mrio.extension_contains("emission")
print("Extension search for 'emission':", extension_search)

# Full match search
match_results = test_mrio.match("reg1")
print("Full match for 'reg1':", match_results)

# %% [markdown]
# **Tip**: Use the find method to get a quick overview where you find a specific term, in particular for mrio systems with multiple extensions.
# For example, the following finds "air" in the compartment information of one extension.

# %%
print("Search for occurance of >air< in the whole system:", test_mrio.find("air"))


# %% [markdown]
# ## Core Calculations with calc_all
#
# The `calc_all` method is fundamental to pymrio analysis. It automatically identifies missing tables and calculates all necessary accounts:


# %% [markdown]
# Before the calculation, we have the following accounts available in the test MRIO system:

# %%
print("Before calc_all:")
print(test_mrio.DataFrames)
print(test_mrio.emissions.DataFrames)

# %% [markdown]
# Calculate all missing parts

# %%
test_mrio.calc_all()

# %% [markdown]
# After calculation, these accounts are available

# %%
print("After calc_all:")
print(test_mrio.DataFrames)

# %% [markdown]
# And we now also have several classical EE-MRIO results available:

# %%
print("\nEmissions accounts:")
print(test_mrio.emissions.DataFrames)

# %% [markdown]
# For example

# %%
print("D_cba (consumption-based):", test_mrio.emissions.D_cba)

# %% [markdown]
# ## Ghosh Calculations in calc_all
#
# When `calc_all` is executed, it can optionally calculate Ghosh inverse matrices for downstream analysis:

# %%
test_mrio.calc_all(include_ghosh=True)
print(test_mrio)

# %% [markdown]
# This also calculates downstream multipliers M_down

# %%
test_mrio.emissions.M_down

# %% [markdown]
# See the [math section](../math.rst) of the documentation for further details on the Ghosh calculations.


# %% [markdown]
# ## Search and Extract Functionality

# %% [markdown]
# ### Extracting Specific Accounts

# %% [markdown]
# We can also extract consumption-based accounts for a specific stressor

# %%
cba_emission1 = test_mrio.emissions.D_cba.loc[["emission_type1"]]
print("CBA emissions by region for emission_type1:")
print(cba_emission1)

# %% [markdown]
# And extract data for specific regions:

# %%
reg1_data = test_mrio.emissions.D_cba_reg[["reg1", "reg3"]]
print("\nTotal CBA emissions for the selected regions:")
print(reg1_data)

# %% [markdown]
# Besides the direct access to the DataFrames explained above, one can also
# extract data into dictionaries for alternative access.:

# %%
emission_type1_data = test_mrio.emissions.get_row_data("emission_type1")


# %% [markdown]
# This extracts all data available for >emission_type1<

# %%
emission_type1_data.keys()


# %% [markdown]
# ### Advanced Search Patterns
#
# Use regular expressions for more complex searches:

# %%
emis_search = test_mrio.find("emission.*")
print("Emission... occurances:", emis_search)

all_extension_search = test_mrio.extension_contains("typ+")
print("Extensions containing 'type':", all_extension_search)


# %% [markdown]
# ## Using Functions from iomath
#
# Pymrio's `iomath` module provides low-level functions for specific calculations:
#
# import numpy as np

# %%
from pymrio.tools import iomath

# Calculate specific matrices manually
A_manual = iomath.calc_A(test_mrio.Z, test_mrio.x)
print("Manual A matrix calculation matches:", np.allclose(A_manual, test_mrio.A))

# Calculate Leontief matrix
L_manual = iomath.calc_L(test_mrio.A)
print("Manual L matrix calculation matches:", np.allclose(L_manual, test_mrio.L))

# Calculate multipliers
S = test_mrio.emissions.S
M_manual = iomath.calc_M(S, test_mrio.L)
print(
    "Manual multiplier calculation matches:",
    np.allclose(M_manual, test_mrio.emissions.M),
)

# %% [markdown]
# ## Gross Trade Analysis
#
# The `calc_gross_trade` function provides insights into bilateral trade flows:

# %%
gross_trade = test_mrio.get_gross_trade()

# %% [markdown]
# This give the total trade flows from one region/sectors to other regions

# %%
gross_trade.bilat_flows.head()


# %% [markdown]
# As well as the totals for each region

# %%
gross_trade.totals.head()

# %% [markdown]
# ## Extension Methods: Concatenate, Convert, and Characterize

# %% [markdown]
# ### Extension Concatenation
#
# The `extension_concate` method allows combining multiple extensions.

# %%
# Create a copy for demonstration
ext_emis2 = test_mrio.emissions.copy()
# Combine two extensions with same index structure
new_ext = pymrio.extension_concate(
    test_mrio.emissions, ext_emis2, new_extension_name="emissions_combined"
)
new_ext.rows

# %% [markdown]
# Combining extensions with different indicies results in a new index called >indicator<. Any indicies not avaialable in one of the extensions is set to NaN.

# %%
all_ext = pymrio.extension_concate(
    test_mrio.emissions, test_mrio.factor_inputs, new_extension_name="All"
)
print(all_ext)
all_ext.rows

# %% [markdown]
# In any case, the extension can be attached to the mrio object and used alongside the others.

# %%
test_mrio.all_ext = all_ext
print(test_mrio.extensions)
print(test_mrio.extensions_instance_names)

# %% [markdown]
# ### Extension Conversion
#
# The `convert` and and `extension_convert` methods transforms extensions based on mapping functions:

# %%
import pandas as pd

conversion_factors = pd.DataFrame(
    columns=[
        "stressor",
        "compartment",
        "total__stressor",
        "factor",
        "unit_orig",
        "unit_new",
    ],
    data=[
        ["emis.*", "air|water", "total_sum_tonnes", 1e-3, "kg", "t"],
        ["emission_type[1|2]", ".*", "total_sum", 1, "kg", "kg"],
        ["emission_type1", ".*", "air_emissions", 1e-3, "kg", "t"],
        ["emission_type2", ".*", "water_emissions", 1000, "kg", "g"],
        ["emission_type1", ".*", "char_emissions", 2, "kg", "kg_eq"],
        ["emission_type2", ".*", "char_emissions", 10, "kg", "kg_eq"],
    ],
)

# %% [markdown]
# Importantly, the columns names >stressor< and >compartment< match the index names of the extension to be converted.
# Bridge columns are columns with '__' in the name. They defined a new name >impact< and how it is based on a previous column name.
# The column >Factor< is the conversion factor, and the last 2 columns define new colums and check the orignal ones.

# %%
new_emis = test_mrio.emissions.convert(
    conversion_factors, new_extension_name="converted_emissions"
)
new_emis.F

# %% [markdown]
# **Tip**: Due to the regular expression capabilities this function
# is quite powerful but also rather slow.
# Use is before doing the full analysis, and use the characterization function
# for "standard" characterization tasks (see below).
#

# %% [markdown]
# ### Characterization of stressors
#
# Pymrio uses an innovative string-matching approach to characterize stressors.
# This method matches stressors in the characterization table (in long format)
# with those in the MRIO system, ensuring consistent stressor mapping,
# automatic unit verification, and flexibility regardless of entry order. It
# also handles characterization factors for stressors not present in the
# satellite account, efficiently manages region- and sector-specific factors,
# and supports characterization across different extensions.
#
# Unlike traditional matrix multiplication methods, which require strict 1:1
# correspondence and precise ordering, this approach is more flexible.
# Characterization can be performed using either an extension object method or
# a top-level function that accepts MRIO objects or extension collections.
#
# To start, we need to first define a characterization factors table.

# %%
char_factors = pd.DataFrame(
    {
        "stressor": ["emission_type1", "emission_type2", "emission_type3"],
        "compartment": ["air", "water", "land"],
        "impact": ["climate_change", "acidification", "eutrophication"],
        "factor": [25.0, 1.5, 0.8],  # kg CO2-eq, SO2-eq, PO4-eq
        "impact_unit": ["kg CO2-eq", "kg SO2-eq", "kg PO4-eq"],
        "stressor_unit": ["kg", "kg", "kg"],
    }
)

# %% [markdown]
# This can be used to characterize the emissions extension of the test MRIO system.

# %%
characterization_result = test_mrio.emissions.characterize(
    factors=char_factors,
    characterized_name_column="impact",
    characterization_factors_column="factor",
    characterized_unit_column="impact_unit",
    orig_unit_column="stressor_unit",
)

# %% [markdown]
# The result contains a validation table, informing about the missing stressor.
#

# %%
characterization_result.validation

# %% [markdown]
# **TIP**: Alway verify and check via the validation table.
# It is also returned in cases when the characterization can not be performed (e.g. due to unit errors).

# %% [markdown]
# The characterized is available as the second attribute of the result:

# %%
characterization_result.extension

# %%
characterization_result.extension.F

# %% [markdown]
# For more details on region-specific characterization and characterization
# across multiple extensions, see the notebook stressor_characterization.

# %% [markdown]
# ## Parsing, saving and loading MRIOs


# %% [markdown]
# ### Parsing MRIOs
#
# Pymrio supports any symmetric MRIO table and provides automatic downloading and parsing for several common datasets.
# For details, see the sections "Automatic MRIO download" and "Handling MRIO data".


# %% [markdown]
# ### Saving processed MRIOs
# You can save your MRIO after you've parsed and analysed it. Pymrio lets you
# save in text, pickle or parquet formats. Parquet works well if your dataset is on the
# larger side.
#
#
#
# import os

# %%
import tempfile
from pathlib import Path

# Create temporary directory for demonstration
temp_dir = Path(tempfile.mkdtemp())


# %% [markdown]
# The difference for into the supported formats it given by the argument to the >save_all< method

# %%
# Save to text format
txt_path = temp_dir / "test_mrio_txt"
test_mrio.save_all(txt_path, table_format="txt")
list(txt_path.glob("**/*"))


# %%
# Save to parquet format
parquet_path = temp_dir / "test_mrio_parquet"
test_mrio.save_all(parquet_path, table_format="parquet")
list(parquet_path.glob("**/*"))


# %% [markdown]
# In both cases, each DataFrame (account) is stored as separate file,
# with satellite accounts a subfolders. The file >file_paramters.json<
# stores the definition of index/columns such that files can be read
# back in correctly.

# %%
mrio_reload_txt = pymrio.load_all(txt_path)
mrio_reload_parquet = pymrio.load_all(parquet_path)
print(test_mrio)
print(mrio_reload_txt)
print(mrio_reload_parquet)

# %% [markdown]
# Clean up temporary directory

# %%
import shutil

shutil.rmtree(temp_dir)
print("Temporary files cleaned up")


# %% [markdown]
# ## Conclusion
#
#
# We covered the main functionality of pymrio in this tutorial.
#
# Pymrio has many more features, including aggregation, renaming and restructuring, and analysing the source of stressors. You can explore these topics in more detail in the following example notebooks:
#
# - [Aggregation Examples](aggregation_examples.ipynb)
# - [Adjusting, Renaming and Restructuring](adjusting.ipynb)
# - [Analysing the Source of Stressors (Flow Matrix)](buildflowmatrix.ipynb)
#
# For working with specific MRIO databases, see for example:
#
# - [EXIOBASE](working_with_exiobase.ipynb)
# - [WIOD](working_with_wiod.ipynb)
# - [GLORIA](working_with_gloria.ipynb)
# - [OECD-ICIO](working_with_oecd_icio.ipynb)
#
# You can also check the [API Reference](../api_references.rst) for a full overview of available functions and classes.
#
# If you have questions or need help, please open an issue on our [GitHub page](https://github.com/IndEcol/pymrio). We're happy to help!
#
# Thank you for following the tutorial, and good luck with your MRIO analyses!



# ---
# jupyter:
#   jupytext:
#     formats: ipynb,py:light
#     text_representation:
#       extension: .py
#       format_name: light
#       format_version: '1.5'
#       jupytext_version: 1.16.4
#   kernelspec:
#     display_name: Python 3 (ipykernel)
#     language: python
#     name: python3
# ---

# # Adjusting, Renaming and Restructuring

# In this tutorial we will cover how to modify the structure of an MRIO system.
# This includes renaming sectors, regions and Y categories,
# as well as restructuring (extracting and merging) satellite accounts.


# We use the small test MRIO system that is included in the pymrio package for all examples.
# The method work the same for any MRIO system.

import pymrio

mrio = pymrio.load_test()

# We can use several functions to get a quick overview over the MRIO system [(see the Exploring MRIO tutorial for more examples)](explore.ipynb).

mrio.get_sectors()

mrio.get_regions()

mrio.get_Y_categories()

# A list of available satellite accounts can be obtained by

mrio.get_extensions()

# this returns a generator over all extensions, to just get the names which can be used to loop over the extensions. To just get the names:

list(mrio.get_extensions())

# ## Renaming

# ### Manual renaming

# All the names returned are literally just names and can easily be renamed.
# To rename sectors or regions just pass a dictionary with the new names:

mrio.rename_regions({"reg1": "REGION A", "reg2": "REGION B"})

mrio.get_regions()

# Renaming sectors or Y categories works the same way

mrio.rename_sectors({"mining": "dwarf business"})
mrio.rename_Y_categories({"Final consumption expenditure by households": "fin_house"})

mrio.get_sectors()

mrio.get_Y_categories()

# ### Renaming based on included classifications synonyms

# Some MRIOs come with a selections of names which can be used for renaming.
# These can be obtained via 'get_classification', passing the name of the IO (pass None to get a list of available classifications).

mrio_class = pymrio.get_classification(mrio_name="test")

# The classification data contains different names and aggregation levels for the sectors and final demand categories. The easiest way to explore the classification data is by using the autocomplete functionality. Depending on the editor your are using this might work with typing mrio_class.sectors. pressing Tab or Ctrl-Space. The same works for mrio_class.finaldemand.

# Alternatively it is possible to just print the underlying dataframes with (similar for finaldemand)

mrio_class.sectors

# This can be used to generate dictionaries for renaming the sectors of the MRIO, eg with:

conv_dict = mrio_class.get_sector_dict(
    mrio_class.sectors.TestMrioName, mrio_class.sectors.TestMrioCode
)
conv_dict

# This can then be used for renaming the sectors:

mrio = pymrio.load_test()

mrio.rename_sectors(conv_dict)
mrio.get_sectors()


# In the mrio_class.sectors you will also find an entry 'Type' which
# represents a many to one mapping.
# This can be used for aggregating the
# MRIO and is explained [in the aggregation tutorial](aggregation_examples.ipynb#Aggregation-by-renaming).

# # Extracting satellite accounts

# Each extension/satellite account of the MRIO contains a method 'extract'.
# This takes an index and extracts the corresponding satellite account entries.
# The index can either be obtained manually, or one can use the contains/match/fullmatch methods of the extension to get the index.

# Below we extract all extensions rows from the emission satallite account which contain the word 'air'.

air_emission_index = mrio.emissions.contains("air")
air_accounts_dict = mrio.emissions.extract(index=air_emission_index)

# The result is a dictionary with the extracted satellite accounts. The keys are the names of the satellite accounts and the values are the extracted satellite accounts.

air_accounts_dict.keys()

# Alternatively, one can automatically convert the extracted satellite accounts to a new MRIO extension.

air_accounts_extension = mrio.emissions.extract(
    index=air_emission_index, return_type="extension"
)
print(air_accounts_extension)

# The extract method can also be applied over all extensions.
# This work well in combinaton with the contains/match/fullmatch methods of the extension.

# Satellite accounts can be extracted from the MRIO system
# by using the extension_extract method.
# This method takes the name of the satellite account as first argument
# and a list of regions as second argument.
# The regions can be given as a list of region names or as a list of region indices.
# The method returns a new MRIO system with the extracted satellite account.

# In the somehow derived example below we extract entries accross
# all accounts that contain the word 'Added' or the letter 2.

cross_accounts_index = mrio.extension_contains("Added|2")

# We can also extract all data from the satellite accounts with these indexes.

cross_accounts_dict = mrio.extension_extract(cross_accounts_index)

# This returns a dictionary of dictionaries with the extracted satellite accounts.

cross_accounts_dict.keys()

cross_accounts_dict["Emissions"].keys()

# Again, we can also build a new MRIO extension from the extracted satellite accounts.

# This can be either one per extension (by passing return_type="extension")

cross_accounts_extension = mrio.extension_extract(
    cross_accounts_index, return_type="extension"
)

# Or by passing any other string to return_type, which will be used as the new name of the extension.

cross_accounts_all_new = mrio.extension_extract(
    cross_accounts_index, return_type="new_name"
)

print(cross_accounts_all_new)

# Index values levels and names of the new extension are based on the combination
# of the original extensions index levels.
# These are filled for nan for entries which did not have them before.

cross_accounts_all_new.get_rows()

# Both extract methods, extension_extract and extract, can also be used to extract only
# a subset of the available dataframe accounts. This can be done by passing a list of
# dataframe names to the dataframes parameter.

only_fys = mrio.extension_extract(
    cross_accounts_index, dataframes=["F_Y"], include_empty=True
)

only_fys.keys()
only_fys["Emissions"].keys()



"""
Pymrio - A python module for automating io calculations and generating reports
==============================================================================

The classes and tools in this module should work with any symetric IO system.

The main class of the module (IOSystem) has attributes .A, .L, ...
corresponding to a standard IO classification.
Data can be assigned directly to the attributes or by calling the
parsing or load functions.

Data storage
------------
Txt files together with a ini file are used for storing data. In addition,
the IOSystem with all data can also be pickled (binary).


Misc
----

Standard abbreviation for that module: mr

"""

from pymrio.core.fileio import *
from pymrio.core.mriosystem import (
    Extension,
    IOSystem,
    extension_characterize,
    extension_concate,
    extension_convert,
)
from pymrio.tools.ioclass import ClassificationData, get_classification
from pymrio.tools.iodownloader import (
    download_eora26,
    download_exiobase1,
    download_exiobase2,
    download_exiobase3,
    download_gloria,
    download_oecd,
    download_wiod2013,
)
from pymrio.tools.iomath import (
    calc_A,
    calc_accounts,
    calc_B,
    calc_e,
    calc_F,
    calc_F_Y,
    calc_G,
    calc_gross_trade,
    calc_L,
    calc_M,
    calc_M_down,
    calc_S,
    calc_S_Y,
    calc_x,
    calc_x_from_L,
    calc_Z,
)
from pymrio.tools.iometadata import MRIOMetaData
from pymrio.tools.ioparser import *
from pymrio.tools.ioutil import (
    build_agg_matrix,
    build_agg_vec,
    convert,
    extend_rows,
    index_contains,
    index_fullmatch,
    index_match,
    to_long,
)
from pymrio.version import __version__



# ---
# jupyter:
#   jupytext:
#     text_representation:
#       extension: .py
#       format_name: percent
#       format_version: '1.3'
#       jupytext_version: 1.15.0
#   kernelspec:
#     display_name: Python 3 (ipykernel)
#     language: python
#     name: python3
# ---

# %% [markdown]
# # Loading, saving and exporting data

# %% [markdown]
# Pymrio includes several functions for data reading and storing. This section presents the methods to use for saving and loading data already in a pymrio compatible format. For parsing raw MRIO data see the different tutorials for [working with available MRIO databases](../handling.rst).

# %% [markdown]
# Here, we use the included small test MRIO system to highlight the different function. The same functions are available for any MRIO loaded into pymrio. Expect, however, significantly decreased performance due to the size of real MRIO system.

import os

# %%
import pymrio

io = pymrio.load_test().calc_all()

# %% [markdown]
# ## Basic save and read

# %% [markdown]
# To save the full system, use:

# %%
save_folder_full = "/tmp/testmrio/full"
io.save_all(path=save_folder_full)

# %% [markdown]
# To read again from that folder do:

# %%
io_read = pymrio.load_all(path=save_folder_full)

# %% [markdown]
# The fileio activities are stored in the included meta data history field:

# %%
io_read.meta

# %% [markdown]
# ## Storage format

# %% [markdown]
# Internally, pymrio stores data in csv format, with the 'economic core' data in the root and each satellite account in a subfolder. Metadata as file as a file describing the data format ('file_parameters.json') are included in each folder.

# %%
import os

os.listdir(save_folder_full)

# %% [markdown]
# The file format for storing the MRIO data can be switched to a binary pickle format with:

# %%
save_folder_bin = "/tmp/testmrio/binary"
io.save_all(path=save_folder_bin, table_format="pkl")
os.listdir(save_folder_bin)

# %% [markdown]
# This can be used to reduce the storage space required on the disk for large MRIO databases.

# %% [markdown]
# ## Archiving MRIOs databases

# %% [markdown]
# To archive a MRIO system after saving use pymrio.archive:

# %%
mrio_arc = "/tmp/testmrio/archive.zip"

# Remove a potentially existing archive from before
try:
    os.remove(mrio_arc)
except FileNotFoundError:
    pass

pymrio.archive(source=save_folder_full, archive=mrio_arc)

# %% [markdown]
# Data can be read directly from such an archive by:

# %%
tt = pymrio.load_all(mrio_arc)

# %% [markdown]
# Currently data can not be saved directly into a zip archive.
# It is, however, possible to remove the source files after archiving:

# %%
tmp_save = "/tmp/testmrio/tmp"

# Remove a potentially existing archive from before
try:
    os.remove(mrio_arc)
except FileNotFoundError:
    pass

io.save_all(tmp_save)

print("Directories before archiving: {}".format(os.listdir("/tmp/testmrio")))
pymrio.archive(source=tmp_save, archive=mrio_arc, remove_source=True)
print("Directories after archiving: {}".format(os.listdir("/tmp/testmrio")))

# %% [markdown]
# Several MRIO databases can be stored in the same archive:

# %%
# Remove a potentially existing archive from before
try:
    os.remove(mrio_arc)
except FileNotFoundError:
    pass

tmp_save = "/tmp/testmrio/tmp"

io.save_all(tmp_save)
pymrio.archive(
    source=tmp_save, archive=mrio_arc, path_in_arc="version1/", remove_source=True
)
io2 = io.copy()
del io2.emissions
io2.save_all(tmp_save)
pymrio.archive(
    source=tmp_save, archive=mrio_arc, path_in_arc="version2/", remove_source=True
)

# %% [markdown]
# When loading from an archive which includes multiple MRIO databases, specify
# one with the parameter 'path_in_arc':

# %%
io1_load = pymrio.load_all(mrio_arc, path_in_arc="version1/")
io2_load = pymrio.load_all(mrio_arc, path_in_arc="version2/")

print(
    "Extensions of the loaded io1 {ver1} and of io2: {ver2}".format(
        ver1=sorted(io1_load.get_extensions()), ver2=sorted(io2_load.get_extensions())
    )
)

# %% [markdown]
# The pymrio.load function can be used directly to only a specific satellite account
# of a MRIO database from a zip archive:

# %%
emissions = pymrio.load(mrio_arc, path_in_arc="version1/emissions")
print(emissions)

# %% [markdown]
# The archive function is a wrapper around python.zipfile module.
# There are, however, some differences to the defaults choosen in the original:
#
# -  In contrast to [zipfile.write](https://docs.python.org/3/library/zipfile.html),
#    pymrio.archive raises an
#    error if the data (path + filename) are identical in the zip archive.
#    Background: the zip standard allows that files with the same name and path
#    are stored side by side in a zip file. This becomes an issue when unpacking
#    this files as they overwrite each other upon extraction.
#
# -  The standard for the parameter 'compression' is set to ZIP_DEFLATED
#    This is different from the zipfile default (ZIP_STORED) which would
#    not give any compression.
#    See the [zipfile docs](https://docs.python.org/3/library/zipfile.html#zipfile-objects)
#    for further information.
#    Depending on the value given for the parameter 'compression'
#    additional modules might be necessary (e.g. zlib for ZIP_DEFLATED).
#    Futher information on this can also be found in the zipfile python docs.

# %% [markdown]
# ## Storing or exporting a specific table or extension

# %% [markdown]
# Each extension of the MRIO system can be stored separetly with:

# %%
save_folder_em = "/tmp/testmrio/emissions"

# %%
io.emissions.save(path=save_folder_em)

# %% [markdown]
# This can then be loaded again as separate satellite account:

# %%
emissions = pymrio.load(save_folder_em)

# %%
emissions

# %%
emissions.D_cba

# %% [markdown]
# As all data in pymrio is stored as [pandas DataFrame](https://pandas.pydata.org/pandas-docs/stable/generated/pandas.DataFrame.html), the full pandas stack for exporting tables is available. For example, to export a table as excel sheet use:

# %%
io.emissions.D_cba.to_excel("/tmp/testmrio/emission_footprints.xlsx")

# %% [markdown]
# For further information see the pandas [documentation on import/export](https://pandas.pydata.org/pandas-docs/stable/io.html).
